@@ -5,7 +5,7 @@ param.poisson.mixed <- function(obj, num=1000, ...) {
   obj <- GetObject(obj)
 
   # this is kludge, while functions are not being forwarded correctly
-  sigma <- getMethod('sigma', 'mer')
+  # sigma <- getMethod('sigma', 'mer')  approach stopped working
 
   fixed <- fixef(obj)
   vars <- ranef(obj, postVars=TRUE)
@@ -24,7 +24,7 @@ param.poisson.mixed <- function(obj, num=1000, ...) {
 
   names(gammas) <- names(vars)
   betas <- mvrnorm(num, fixef(obj), vcov(obj))
-  scale <- sigma(obj)
+  scale <- lme4::sigma(obj)
 
   list(
        coef = betas,
